# Changelog

All notable changes to this project will be documented. If you have any updates you would like to see, please create a GitHub issue or contact us at info@sciris.org.

By import convention, components of the ScirisWeb library are listed beginning with `sw.`, e.g. `sw.ScirisApp()`.

## Version 0.17.1 (2022-02-02)
1. Fixed regression issue with Sciris.
2. Tests switched from Travis CI to GitHub Actions.

## Version 0.17.0 (2020-04-27)
1. Tests reorganized.